 # Getting started

The following documents will give you an overview of how to install and use
napari. For more detailed use-cases, check out the [napari tutorials](./index)
or [How-to guides](../howtos/index).

::::{grid}
:::{grid-item-card} napari quick start
:link: napari-quick-start
:link-type: ref

A quick glance of what napari does aimed at first-timers.
:::
::::

::::{grid}
:::{grid-item-card} How to install napari
:link: installation
:link-type: ref

How to do a clean install of napari and launch the viewer.
:::

:::{grid-item-card} Getting started
:link: getting-started
:link-type: ref

This tutorial will teach you all the different ways to launch napari.
:::
::::

::::{grid}
:::{grid-item-card} napari viewer tutorial
:link: viewer-tutorial
:link-type: ref

This tutorial will teach you about the napari viewer, including how to use its graphical user interface (GUI)
and how the data within it is organized.
:::

:::{grid-item-card} Layers at a glance
:link: layers-glance
:link-type: ref

An overview of the napari *Layers*, the basic viewable objects that can be displayed on the canvas.
:::
::::